/*
 * Copyright (c) 2011 Samsung Electronics Co., Ltd All Rights Reserved
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 */
/**
 * @file        StaticAssert.h
 * @author      Zbigniew Kostrzewa (z.kostrzewa@samsung.com)
 * @author      Grzegorz Krawczyk (g.krawczyk@samsung.com)
 * @version     0.1
 */

#ifndef WRTDEVICEAPIS_COMMONS_STATIC_ASSERT_H
#define WRTDEVICEAPIS_COMMONS_STATIC_ASSERT_H

namespace WrtDeviceApis {
namespace Commons {

template<bool>
struct CompileTimeChecker
{
    CompileTimeChecker(...);
};

template<>
struct CompileTimeChecker<false> {};

#define STATIC_CHECK(expr, msg) \
    { \
        class ERROR_ ## msg {}; \
        CompileTimeChecker<(expr)!= 0>((ERROR_ ## msg())); \
    }

/**
 * Define used to inform about errors in compilation time
 * useful in templates
 * @param msg - message to be displayed,
 * msg have to be a valid C++ identifier,
 * other way reported errors will be meaningless
 * @param C - instance of object which caused problem
 * error generated by compiler display type of C
 * */
#define STATIC_ERROR(msg, C) \
    { \
        C->_ ## msg(); \
    }

}
} // WrtDeviceApisCommon

#endif // WRTDEVICEAPIS_COMMONS_STATIC_ASSERT_H
