/*
 * Copyright (c) 2011 Samsung Electronics Co., Ltd All Rights Reserved
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 */
#ifndef WRTDEVICEAPIS_CPU_IMANAGER_H_
#define WRTDEVICEAPIS_CPU_IMANAGER_H_

#include <cstddef>
#include <dpl/noncopyable.h>
#include <Cpu/IUnit.h>

namespace WrtDeviceApis {
namespace Cpu {
namespace Api {

class IManager : private DPL::Noncopyable
{
  public:
    static IManager& getInstance();

  public:
    virtual ~IManager() = 0;

    /**
     * Gets interface to CPU.
     * @param index Index of CPU to get (1-based).
     * @return Interface to CPU.
     * @throw PlatformException If platform error occurs.
     * @throw OutOfRangeException If index is greater than available CPUs.
     * @remarks On some platforms passing 0 as index may return unit object
     *          that gives avarage data for all CPUs. If such interface is
     *          not supported then NULL is returned.
     * @remarks Ownership is NOT passed to the caller.
     */
    virtual IUnit* getUnit(std::size_t index) const = 0;

    /**
     * Gets number of available CPUs.
     * @return Number of CPUs.
     */
    virtual std::size_t getUnitsCount() const = 0;
};

} // Api
} // Cpu
} // WrtDeviceApis

#endif // WRTDEVICEAPIS_CPU_IMANAGER_H_
