/*
 * Copyright (c) 2011 Samsung Electronics Co., Ltd All Rights Reserved
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 */
/*
 * @author      Wojciech Bielawski (w.bielawski@samsung.com)
 * @version     0.1
 * @brief
 */

#ifndef WRTDEVICEAPIS_MMPLAYER_EVENT_ISPLAYING_H_
#define WRTDEVICEAPIS_MMPLAYER_EVENT_ISPLAYING_H_

#include <dpl/shared_ptr.h>
#include <Commons/IEvent.h>
#include <MMPlayer/IMMPlayer.h>

namespace WrtDeviceApis {
namespace MMPlayer {
namespace Api {

class EventIsPlaying : public Commons::IEvent<EventIsPlaying>
{
  private:
    IMMPlayerPtr m_player;
    bool m_isPlaying;

  public:
    /**
     * Getters and setters
     */
    IMMPlayerPtr getPlayer() const
    {
        return m_player;
    }
    void setIsPlaying(bool isPlaying)
    {
        m_isPlaying = isPlaying;
    }
    bool getIsPlaying() const
    {
        return m_isPlaying;
    }

    explicit EventIsPlaying(const IMMPlayerPtr &player) :
        m_player(player),
        m_isPlaying(false)
    {
    }
};

typedef DPL::SharedPtr<EventIsPlaying> EventIsPlayingPtr;
} // MMPlayer
} // Api
} // WrtDeviceApis

#endif // WRTDEVICEAPIS_MMPLAYER_EVENT_ISPLAYING_H_
