/*
 * Copyright (c) 2011 Samsung Electronics Co., Ltd All Rights Reserved
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 */
/*
 * @author      Wojciech Bielawski (w.bielawski@samsung.com)
 * @version     0.1
 * @brief
 */

#ifndef WRTDEVICEAPIS_MMPLAYER_EVENT_PLAY_H_
#define WRTDEVICEAPIS_MMPLAYER_EVENT_PLAY_H_

#include <dpl/shared_ptr.h>
#include <Commons/IEvent.h>
#include <MMPlayer/IMMPlayer.h>

namespace WrtDeviceApis {
namespace MMPlayer {
namespace Api {

class EventPlay : public Commons::IEvent<EventPlay>
{
  private:
    IMMPlayerPtr m_player;
    unsigned int m_repeatTimes;

  public:
    /**
     * Getters
     */
    IMMPlayerPtr getPlayer() const
    {
        return m_player;
    }
    unsigned int getRepeatTimes() const
    {
        return m_repeatTimes;
    }

    explicit EventPlay(const IMMPlayerPtr &player,
                       unsigned int repeatTimes) :
        m_player(player),
        m_repeatTimes(repeatTimes)
    {
    }
};

typedef DPL::SharedPtr<EventPlay> EventPlayPtr;
} // MMPlayer
} // Api
} // WrtDeviceApis

#endif // WRTDEVICEAPIS_MMPLAYER_EVENT_PLAY_H_
