/*
 * Copyright (c) 2011 Samsung Electronics Co., Ltd All Rights Reserved
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 */
/*
 * @author      Wojciech Bielawski (w.bielawski@samsung.com)
 * @version     0.1
 * @brief
 */

#ifndef WRTDEVICEAPIS_MMPLAYER_EVENT_SET_WINDOW_H_
#define WRTDEVICEAPIS_MMPLAYER_EVENT_SET_WINDOW_H_

#include <dpl/shared_ptr.h>
#include <MMPlayer/IMMPlayer.h>
#include <Commons/IEvent.h>

namespace WrtDeviceApis {
namespace MMPlayer {
namespace Api {

class EventSetWindow : public Commons::IEvent<EventSetWindow>
{
  private:
    IMMPlayerPtr m_player;
    int m_posX;
    int m_posY;
    int m_width;
    int m_height;

  public:
    /**
     * Getter
     */
    IMMPlayerPtr getPlayer() const
    {
        return m_player;
    }

    EventSetWindow(const IMMPlayerPtr &player,
            int posX,
            int posY,
            int width,
            int height) :
        m_player(player),
        m_posX(posX),
        m_posY(posY),
        m_width(width),
        m_height(height)
    {
    }
};

typedef DPL::SharedPtr<EventSetWindow> EventSetWindowPtr;
} // MMPlayer
} // Api
} // WrtDeviceApis

#endif // WRTDEVICEAPIS_MMPLAYER_EVENT_SET_WINDOW_H_
